@@ -19,7 +19,7 @@ has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Rep
 
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
-sub addToCommandText {
+sub addCommands {
   my ($self, @commands) = @_;
   push @{$self->commandText}, @commands;
 }
@@ -50,13 +50,13 @@ sub design {
           $self->checkAndCreateNat(\%natInfo);
         }
       }
-    } ## end if ( defined $self->searcherReportFwInfo...)
+    }
   }
   else {
     confess "ERROR: searcherReportFwInfo->type(" . $self->searcherReportFwInfo->type . ") Wrong!";
   }
   return join('', map {"$_\n"} @{$self->commandText});
-} ## end sub design
+}
 
 sub createRule {
   my $self = shift;
@@ -89,7 +89,7 @@ sub createRule {
         $self->checkAndCreateNat(\%natInfo);
       }
     }
-  } ## end if ( defined $self->searcherReportFwInfo...)
+  }
   my ($fromZone, $toZone) = ($self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone);
   my @commands;
   my $aclName = $self->searcherReportFwInfo->parser->getZone($fromZone)->{aclName};
@@ -120,8 +120,8 @@ sub createRule {
       }
     }
   }
-  $self->addToCommandText(@commands);
-} ## end sub createRule
+  $self->addCommands(@commands);
+}
 
 sub createAddrGroup {
   my ($self, $addrs) = @_;
@@ -177,9 +177,9 @@ sub createAddrGroup {
     }
     push @commands, "exit";
   }
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $groupName;
-} ## end sub createAddrGroup
+}
 
 sub createObj {
   my ($self,  $addr)  = @_;
@@ -189,7 +189,7 @@ sub createObj {
   push @commands, "object network $objName";
   push @commands, "range $ipMin $ipMax";
   push @commands, "exit";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $objName;
 }
 
@@ -264,9 +264,9 @@ sub CheckAndCreateNat {
         push @commands, "nat ($fromZone,$toZone) dynamic obj-$mip" if $type eq 'natSrc';
       }
     }
-  } ## end for my $type ( keys %{$param...})
-  $self->addToCommandText(@commands);
-} ## end sub CheckAndCreateNat
+  }
+  $self->addCommands(@commands);
+}
 
 sub checkAndCreateNat {
   my ($self, $param) = @_;
@@ -322,8 +322,8 @@ sub checkAndCreateNat {
           push @commands, "global ($toZone) $poolName $pool";
         }
         push @commands, "nat ($fromZone) $poolName access-list $aclName";
-      } ## end else [ if ( defined $aclName )]
-      $self->addToCommandText(@commands);
+      }
+      $self->addCommands(@commands);
     }
     elsif ($type eq 'natDst') {
       my $natIp  = $param->{$type}{natInfo}{natIp};
@@ -347,10 +347,10 @@ sub checkAndCreateNat {
         }
         push @commands, "static ($toZone,$fromZone) $natIp access-list $aclName";
       }
-      $self->addToCommandText(@commands);
-    } ## end elsif ( $type eq 'natDst')
-  } ## end for my $type ( keys %{$param...})
-} ## end sub checkAndCreateNat
+      $self->addCommands(@commands);
+    }
+  }
+}
 
 sub createDynamicNat {
 
@@ -435,8 +435,8 @@ sub getAclName {
       }
     }
     return $aclName;
-  } ## end elsif ( $type eq 'natDst')
-} ## end sub getAclName
+  }
+}
 
 sub createPoolName {
   my $self = shift;
@@ -488,7 +488,7 @@ sub changeAddressToCommand {
     $result = "object-group $address";
   }
   return $result;
-} ## end sub changeAddressToCommand
+}
 
 sub changeSrvToCommand {
   my ($self,     $srv)  = @_;
@@ -510,7 +510,7 @@ sub changeSrvToCommand {
     }
   }
   return ($protocol, $portCommand);
-} ## end sub changeSrvToCommand
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
