@@ -14,7 +14,7 @@ use Firewall::Utils::Ip;
 
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
-sub addToCommandText {
+sub addCommands {
   my ($self, @commands) = @_;
   push(@{$self->commandText}, @commands);
 }
@@ -63,8 +63,8 @@ sub design1 {
         $commandStr .= "exit";
         push @commandStr, $commandStr;
       }
-    } ## end for my $address ( keys ...)
-  } ## end if ( defined $realIpAndGroup)
+    }
+  }
   my $natIpAndGroup = $designReport->{address}{natIp};
   if (defined $natIpAndGroup) {
     for my $address (keys $natIpAndGroup) {
@@ -86,11 +86,11 @@ sub design1 {
         $commandStr .= "exit";
         push @commandStr, $commandStr;
       }
-    } ## end for my $address ( keys ...)
-  } ## end if ( defined $natIpAndGroup)
-  $self->addToCommandText(@commandStr);
+    }
+  }
+  $self->addCommands(@commandStr);
   return \@commandStr;
-} ## end sub design1
+}
 
 sub design2 {
   my ($self, $designReport) = @_;
@@ -103,7 +103,7 @@ sub design2 {
       }
     }
   }
-  $self->addToCommandText(@commandStr);
+  $self->addCommands(@commandStr);
   return \@commandStr;
 }
 
