@@ -18,7 +18,7 @@ has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Rep
 
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
-sub addToCommandText {
+sub addCommands {
   my ($self, @commands) = @_;
   push(@{$self->commandText}, @commands);
 }
