@@ -13,7 +13,7 @@ use Firewall::Utils::Date;
 
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
-sub addToCommandText {
+sub addCommands {
   my ($self, @commands) = @_;
   push(@{$self->commandText}, @commands);
 }
@@ -51,7 +51,7 @@ sub design1 {
       }
 
     }
-  } ## end for my $rule ( @{$rules...})
+  }
 
   my $realIpAndGroup = $designReport->{address}{realIp};
   if (defined $realIpAndGroup) {
@@ -89,12 +89,12 @@ sub design1 {
       }
     }
 
-  } ## end if ( defined $natIpAndGroup)
+  }
 
-  $self->addToCommandText(@commandStr);
+  $self->addCommands(@commandStr);
 
   return \@commandStr;
-} ## end sub design1
+}
 
 sub design2 {
   my ($self, $designReport) = @_;
@@ -120,13 +120,13 @@ sub design2 {
         $comStr .= "exit\n";
         push @commandStr, $comStr;
       }
-    } ## end if ( ref($rule) eq 'HASH'...)
-  } ## end for my $rule ( @{$rules...})
+    }
+  }
 
-  $self->addToCommandText(@commandStr);
+  $self->addCommands(@commandStr);
 
   return \@commandStr;
-} ## end sub design2
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
