@@ -13,7 +13,7 @@ use Firewall::Utils::Date;
 
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
-sub addToCommandText {
+sub addCommands {
   my ($self, @commands) = @_;
   push(@{$self->commandText}, @commands);
 }
@@ -69,10 +69,10 @@ sub design1 {
     }
   }
 
-  $self->addToCommandText(@commandStr);
+  $self->addCommands(@commandStr);
   return \@commandStr;
 
-} ## end sub design1
+}
 
 sub design2 {
   my ($self, $designReport) = @_;
@@ -96,10 +96,10 @@ sub design2 {
       }
 
     }
-  } ## end for my $rule ( @{$rules...})
-  $self->addToCommandText(@commandStr);
+  }
+  $self->addCommands(@commandStr);
   return \@commandStr;
-} ## end sub design2
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
