@@ -10,69 +10,24 @@ use namespace::autoclean;
 # 加载项目模块
 #------------------------------------------------------------------------------
 use Firewall::Utils::Ip;
-use Firewall::Policy::Searcher::Report::FwInfo;
 
-has dbi => (is => 'ro', does => 'Firewall::DBI::Role', required => 1,);
-
-has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Report::FwInfo', required => 1,);
-
-has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
-
-sub addToCommandText {
-  my ($self, @commands) = @_;
-  push @{$self->commandText}, @commands;
-}
-
-sub design {
-  my $self = shift;
-
-  #delete $self->searcherReportFwInfo->{parser};
-  #print dumper $self->searcherReportFwInfo;exit;
-  if ($self->searcherReportFwInfo->type eq 'new') {
-    $self->createRule;
-  }
-  elsif ($self->searcherReportFwInfo->type eq 'modify') {
-    $self->modifyRule;
-  }
-  elsif ($self->searcherReportFwInfo->type eq 'ignore') {
-    if (defined $self->searcherReportFwInfo->action) {
-      my $param = $self->searcherReportFwInfo->action->{'new'};
-      for my $type (keys %{$param}) {
-        if ($type eq 'natDst' or $type eq 'natSrc') {
-          $self->createNat($param->{$type}, $type);
-        }
-      }
-    }
-  }
-  else {
-    confess("ERROR: searcherReportFwInfo->type(" . $self->searcherReportFwInfo->type . ") must be 'new' or 'modify'");
-  }
-
-=pod
-    if (@{$self->commandText} >0 ){
-        push @{$self->commandText},'save';
-    }
-=cut
-
-  my $parser = $self->searcherReportFwInfo->{parser};
-  if (defined $parser->{isvdom} and $parser->{isvdom} == 1) {
-    unshift @{$self->commandText}, "edit $parser->{vdom}";
-    unshift @{$self->commandText}, "config vdom";
-  }
-  push @{$self->commandText}, "end";
-  return join('', map {"$_\n"} @{$self->commandText});
-} ## end sub design
+#------------------------------------------------------------------------------
+# 继承防火墙策略角色定义的方法属性和相关约定
+#------------------------------------------------------------------------------
+with "Firewall::Policy::Designer::Role";
 
+#------------------------------------------------------------------------------
+# FORTINET防火墙策略设计相关模块
+#------------------------------------------------------------------------------
 sub createRule {
-  my $self   = shift;
-  my $action = $self->searcherReportFwInfo->action->{'new'};
-
-  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($action);
+  my $self     = shift;
+  my $action   = $self->searcherReportFwInfo->action->{new};
+  my $mappings = $self->checkAndCreateAddrOrSrvOrNat($action);
 
 =pod
-    my $natString = '';
-    $natString .= $nameMap->{natSrc}->[0]->{natStr} if defined $nameMap->{natSrc};
-    $natString .= $nameMap->{natDst}->[0]->{natStr} if defined $nameMap->{natDst};
+  my $natString = '';
+  $natString .= $nameMap->{natSrc}->[0]->{natStr} if defined $nameMap->{natSrc};
+  $natString .= $nameMap->{natDst}->[0]->{natStr} if defined $nameMap->{natDst};
 =cut
 
   my $schedule     = $self->searcherReportFwInfo->{schedule};
@@ -82,32 +37,29 @@ sub createRule {
   my @commands;
   my ($srcStr, $dstStr, $srvStr, @natStr);
 
-  for my $type (keys %{$nameMap}) {
+  for my $type (keys %{$mappings}) {
     if ($type eq 'src') {
       $srcStr = "set srcaddr";
-      for my $host (@{$nameMap->{$type}}) {
+      for my $host (@{$mappings->{$type}}) {
         $srcStr .= qq{ "$host"};
       }
-
     }
     elsif ($type eq 'dst') {
       $dstStr = "set dstaddr";
-      for my $host (@{$nameMap->{$type}}) {
+      for my $host (@{$mappings->{$type}}) {
         $dstStr .= qq{ "$host"};
       }
-
     }
     elsif ($type eq 'srv') {
       $srvStr = "set service";
-      for my $srv (@{$nameMap->{$type}}) {
+      for my $srv (@{$mappings->{$type}}) {
         $srvStr .= qq{ "$srv"};
       }
     }
     elsif ($type eq 'natSrc') {
-      @natStr = @{$nameMap->{$type}};
+      @natStr = @{$mappings->{$type}};
     }
-
-  } ## end for my $type ( keys %{$nameMap...})
+  }
 
   push @commands, "config firewall policy";
   push @commands, "edit 0";
@@ -121,22 +73,23 @@ sub createRule {
   push @commands, @natStr if @natStr >= 1;
   push @commands, "next";
   push @commands, "end";
+  $self->addCommands(@commands);
+}
 
-  $self->addToCommandText(@commands);
-} ## end sub createRule
-
+#------------------------------------------------------------------------------
+# FORTINET防火墙策略修改函数
+#------------------------------------------------------------------------------
 sub modifyRule {
   my $self    = shift;
-  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{'add'});
-  if (defined $self->searcherReportFwInfo->action->{'new'}) {
-    my $param = $self->searcherReportFwInfo->action->{'new'};
-    for my $type (keys %{$param}) {
+  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{add});
+  if (my $action = $self->searcherReportFwInfo->action->{new}) {
+    for my $type (keys %{$action}) {
       if ($type eq 'natDst' or $type eq 'natSrc') {
-        $self->createNat($param->{$type}, $type);
-
+        $self->createNat($action->{$type}, $type);
       }
     }
   }
+
   my $policyId = $self->searcherReportFwInfo->ruleObj->policyId;
   my @commands;
   my @addMemeberCommands;
@@ -148,7 +101,6 @@ sub modifyRule {
         $srcStr .= qq{ "$host"};
       }
       push @addMemeberCommands, $srcStr;
-
     }
     elsif ($type eq 'dst') {
       $self->searcherReportFwInfo->ruleObj->content =~ /^\s*(?<dstStr>set\s+dstaddr.+")\s*$/mi;
@@ -157,7 +109,6 @@ sub modifyRule {
         $dstStr .= qq{ "$host"};
       }
       push @addMemeberCommands, $dstStr;
-
     }
     elsif ($type eq 'srv') {
       $self->searcherReportFwInfo->ruleObj->content =~ /^\s*(?<srvStr>set\s+service.+")\s*$/mi;
@@ -166,10 +117,8 @@ sub modifyRule {
         $srvStr .= qq{ "$srv"};
       }
       push @addMemeberCommands, $srvStr;
-
     }
-
-  } ## end for my $type ( keys %{$nameMap...})
+  }
   if (@addMemeberCommands == 0) {
     confess("ERROR: 需要增加的成员数量为0，这不可能!!!!!!");
   }
@@ -179,73 +128,25 @@ sub modifyRule {
   push @commands, @addMemeberCommands;
   push @commands, qq{next};
   push @commands, qq{end};
-
-  $self->addToCommandText(@commands);
-
-} ## end sub modifyRule
-
-sub checkAndCreateAddrOrSrvOrNat {
-  my ($self, $param) = @_;
-  my $nameMap;
-
-  #如果要新建静态NAT，则对应ip不需要要建地址，直接使用MIP()形式
-  my $requestNat = 0;
-  for my $type (keys %{$param}) {
-    if ($type eq 'natDst') {
-      $requestNat = 1;
-    }
-  }
-  for my $type (keys %{$param}) {
-    if ($type eq 'natDst' or $type eq 'natSrc') {
-      $nameMap->{$type} = $self->createNat($param->{$type}, $type);
-    }
-    else {
-      for my $addrOrSrv (keys %{$param->{$type}}) {
-        if (not defined $param->{$type}{$addrOrSrv}) {
-          my $func = "create" . (ucfirst $type);    #createSrc, createDst, createSrv
-          push @{$nameMap->{$type}}, $self->$func($addrOrSrv, $requestNat);
-        }
-        else {
-          push @{$nameMap->{$type}}, $param->{$type}{$addrOrSrv}[0];
-        }
-      }
-    }
-  }
-  return $nameMap;
-} ## end sub checkAndCreateAddrOrSrvOrNat
-
-sub createNat {
-  my ($self, $param, $type) = @_;
-  my $natStrs;
-  my $dyNatInfo = {};
-  for my $natInfo (values %{$param}) {
-    if ($natInfo->{natInfo}->{natType} eq 'static') {
-      $self->createStaticNat($natInfo);
-    }
-    else {
-      $dyNatInfo->{$type}{$natInfo->{natInfo}}{$natInfo->{realIp}} = $natInfo;
-    }
-  }
-  if (scalar(values %{$dyNatInfo}) != 0) {
-    $natStrs = $self->createDyNat($dyNatInfo);
-  }
-  return $natStrs;
+  $self->addCommands(@commands);
 }
 
+#------------------------------------------------------------------------------
+# 创建静态地址转换
+#------------------------------------------------------------------------------
 sub createStaticNat {
   my ($self, $natInfo) = @_;
 
 =pod
-config firewall vip
-    edit "58.60.230.8-443"
-        set extip 58.60.230.8
-        set extintf "vlan-104-telcom"
-        set portforward enable
-        set mappedip 10.3.76.66
-        set extport 443
-        set mappedport 443
-    next
-
+  config firewall vip
+  edit "58.60.230.8-443"
+    set extip 58.60.230.8
+    set extintf "vlan-104-telcom"
+    set portforward enable
+    set mappedip 10.3.76.66
+    set extport 443
+    set mappedport 443
+  next
 =cut
 
   my $natIp         = $natInfo->{natInfo}{natIp};
@@ -258,10 +159,12 @@ config firewall vip
   push @commands, qq{set mappedip $natInfo->{realIp}};
   push @commands, "next";
   push @commands, "end";
-  $self->addToCommandText(@commands);
-
+  $self->addCommands(@commands);
 }
 
+#------------------------------------------------------------------------------
+# 创建动态地址转换
+#------------------------------------------------------------------------------
 sub createDyNat {
   my ($self, $param) = @_;
   for my $type (keys %{$param}) {
@@ -281,16 +184,19 @@ sub createDyNat {
           push @commands, qq{set poolname "$poolName"};
           return \@commands;
         }
-
       }
-    } ## end for my $natIps ( values...)
-  } ## end for my $type ( keys %{$param...})
-} ## end sub createDyNat
+    }
+  }
+}
 
+#------------------------------------------------------------------------------
+# 查询地址转换池
+#------------------------------------------------------------------------------
 sub getOrCreatePool {
   my ($self, $natInfo) = @_;
   my $natIp = $natInfo->{natIp};
   my $natIpSet;
+
   if ($natIp =~ /\d+\.\d+\.\d+\.\d+(\/\d+)?/) {
     my ($ip, $mask) = split('/', $natIp);
     $mask     = 32 if not defined $mask;
@@ -308,18 +214,19 @@ sub getOrCreatePool {
   }
 
 =pod
-config firewall ippool
+  config firewall ippool
     edit "210.21.236.[133-135]-proxyout"
-        set endip 210.21.236.135
-        set startip 210.21.236.133
+      set endip 210.21.236.135
+      set startip 210.21.236.133
     next
-end
+  end
 =cut
 
   my @commands;
   my $poolName = "Pool-$natIp";
   push @commands, "config firewall ippool";
   push @commands, qq{edit "$poolName"};
+
   my ($startIp, $endIp);
   if ($natIp =~ /\d+\.\d+\.\d+\.\d+(\/\d+)?/) {
     my ($ip, $mask) = split('/', $natIp);
@@ -335,23 +242,27 @@ end
   push @commands, "set startip $startIp";
   push @commands, "next";
   push @commands, "end";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $poolName;
+}
 
-} ## end sub getOrCreatePool
-
+#------------------------------------------------------------------------------
+# 创建源地址对象
+#------------------------------------------------------------------------------
 sub createSrc {
   my ($self, $addr, $requestNat) = @_;
   return $self->createAddress($addr, $requestNat);
 }
 
+#------------------------------------------------------------------------------
+# 创建目的地址对象
+#------------------------------------------------------------------------------
 sub createDst {
   my ($self, $addr, $requestNat) = @_;
-  if (defined $self->searcherReportFwInfo->action->{'new'}) {
-    my $param = $self->searcherReportFwInfo->action->{'new'};
-    for my $type (keys %{$param}) {
+  if (my $action = $self->searcherReportFwInfo->action->{new}) {
+    for my $type (keys %{$action}) {
       if ($type eq 'natDst') {
-        for (keys %{$param->{$type}}) {
+        for (keys %{$action->{$type}}) {
           if ($addr eq $_) {
             return "vip$addr";
           }
@@ -362,20 +273,26 @@ sub createDst {
   return $self->createAddress($addr, $requestNat);
 }
 
+#------------------------------------------------------------------------------
+# 创建服务端口对象
+#------------------------------------------------------------------------------
 sub createSrv {
   my ($self, $srv) = @_;
   return $self->createService($srv);
 }
 
+#------------------------------------------------------------------------------
+# 创建地址函数
+#------------------------------------------------------------------------------
 sub createAddress {
   my ($self, $addr, $requestNat) = @_;
 
 =pod
-config firewall address
-edit "office"
-set subnet 192.168.1.0 255.255.255.0
-next
-end
+  config firewall address
+    edit "office"
+    set subnet 192.168.1.0 255.255.255.0
+    next
+  end
 =cut
 
   my ($ip, $mask) = split('/', $addr);
@@ -409,10 +326,13 @@ end
   }
   push @commands, "next";
   push @commands, "end";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $addressName;
-} ## end sub createAddress
+}
 
+#------------------------------------------------------------------------------
+# 创建服务端口函数
+#------------------------------------------------------------------------------
 sub createService {
   my ($self,     $srv)  = @_;
   my ($protocol, $port) = split('/', $srv);
@@ -420,13 +340,13 @@ sub createService {
   return if $protocol ne 'tcp' and $protocol ne 'udp';
 
 =pod
-config firewall service custom
-edit "QQ"
-set protocol TCP/UDP/SCTP
-set tcp-portrange 8000
-set udp-portrange 4000-8000
-next
-end
+  config firewall service custom
+    edit "QQ"
+    set protocol TCP/UDP/SCTP
+    set tcp-portrange 8000
+    set udp-portrange 4000-8000
+    next
+  end
 =cut
 
   my ($serviceName, $dstPort);
@@ -463,10 +383,13 @@ end
   push @commands, "set $protocol-portrange $dstPort";
   push @commands, "next";
   push @commands, "end";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $serviceName;
-} ## end sub createService
+}
 
+#------------------------------------------------------------------------------
+# 创建计划任务
+#------------------------------------------------------------------------------
 sub createSchedule {
   my ($self, $schedule) = @_;
   my @commands;
@@ -477,15 +400,13 @@ sub createSchedule {
   push @commands, "edit \"$year-$mon-$day\"";
   if (defined $schedule->{startdate}) {
     push @commands, "set start $shh:$smm $syear/$smon/$sday";
-
   }
   push @commands, "set end $hh:$mm $year/$mon/$day";
   push @commands, "next";
   push @commands, "end";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return "$year-$mon-$day";
-
-} ## end sub createSchedule
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
