@@ -11,86 +11,25 @@ use namespace::autoclean;
 #------------------------------------------------------------------------------
 use Firewall::Utils::Ip;
 use Firewall::Utils::Set;
-use Firewall::Policy::Searcher::Report::FwInfo;
 
 #------------------------------------------------------------------------------
 # 继承 Firewall::Policy::Designer::Role 通用属性
 #------------------------------------------------------------------------------
-# with 'Firewall::Policy::Designer::Role';
+with 'Firewall::Policy::Designer::Role';
 
 #------------------------------------------------------------------------------
-# Firewall::Policy::Designer::Huawei 通用属性
-#------------------------------------------------------------------------------
-has dbi => (is => 'ro', does => 'Firewall::DBI::Role', required => 1,);
-
-has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Report::FwInfo', required => 1,);
-
-has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
-
-#------------------------------------------------------------------------------
-# addToCommandText 向 commandText 属性推送命令行
-#------------------------------------------------------------------------------
-sub addToCommandText {
-  my ($self, @commands) = @_;
-  push @{$self->{commandText}}, @commands;
-}
-
-#------------------------------------------------------------------------------
-# design 策略设计函数入口，入参为防火墙策略报告 -> searcherReportFwInfo
-#------------------------------------------------------------------------------
-sub design {
-  my $self = shift;
-
-  # 初始化防火墙策略报告下 type action 属性
-  my $type   = $self->{searcherReportFwInfo}{type}   if exists $self->{searcherReportFwInfo}{type};
-  my $action = $self->{searcherReportFwInfo}{action} if exists $self->{searcherReportFwInfo}{action};
-
-  # 情况1：当类型为 new，则新建策略
-  if ($type eq "new") {
-    $self->createRule();
-  }
-
-  # 情况2：当类型为 modify，则修改策略
-  elsif ($type eq "modify") {
-    $self->createRule();
-  }
-
-  # 情况3：当类型为 ignore，还需要检查是否存在 NAT 策略
-  elsif ($type eq "ignore") {
-    my $param = $action->{new} if defined $action;
-    for my $natDirection (keys %{$param}) {
-      if ($natDirection eq "natSrc" || $natDirection eq "natDst") {
-        $self->checkAndCreateNat($param->{$natDirection}, $type);
-      }
-    }
-  }
-
-  # 其他情况：抛出异常，定位排除
-  else {
-    warn "ERROR: searcherReportFwInfo->type(" . $self->{"searcherReportFwInfo"}{"type"} . ") must be 'new' or 'modify'";
-    confess $@;
-  }
-
-  # 拼接数组为字符串并返回
-  return join("\n", @{$self->{"commandText"}});
-} ## end sub design
-
-#------------------------------------------------------------------------------
-# design 策略设计函数入口，入参为防火墙策略报告 -> searcherReportFwInfo
+# 新建防火墙策略
 #------------------------------------------------------------------------------
 sub createRule {
   my $self = shift;
-
-  # 初始化 commands
   my @commands;
 
   # 判断是否需要 nat
   my $action = $self->searcherReportFwInfo->action->{new};
   my $natSrc = $action->{natSrc} if defined $action->{natSrc};
   my $natDst = $action->{natDst} if defined $action->{natDst};
-
-  # 确认是否需要新增 nat
   my $natInfo;
+
   if (defined $natSrc) {
     foreach (values %{$natSrc}) {
       $natInfo->{natSrc} = $_;
@@ -121,10 +60,8 @@ sub createRule {
   push @commands, "source-zone $fromZone";
   push @commands, "destination-zone $toZone";
 
-  # 优先使用动态地址组
+  # 源地址成员大于3，优先使用动态地址组
   my ($srcGroup, $dstGroup);
-
-  # 源地址成员大于3
   if (@srcs > 3) {
     $srcGroup = $self->createAddrGroup(\@srcs);
     push @commands, "source-address address-set $srcGroup";
@@ -134,7 +71,6 @@ sub createRule {
     push @commands, @srcAddrs;
   }
 
-  # 目的地址成员大于3
   if (@dsts > 3) {
     $dstGroup = $self->createAddrGroup(\@dsts);
     push @commands, "destination-address address-set $dstGroup";
@@ -144,16 +80,16 @@ sub createRule {
     push @commands, @dstAddrs;
   }
 
-  # 遍历服务端口成员
-  my @srvsobjs;
+  # 查询或创建服务地址对象
+  my @srvObjs;
   for my $srv (@srvs) {
     my $srvName = $self->createService($srv);
-    push @srvsobjs, $srvName;
+    push @srvObjs, $srvName;
   }
 
   # 推送访问控制服务端口命令行
-  for my $srvobj (@srvsobjs) {
-    push @commands, "service $srvobj";
+  for my $srvObj (@srvObjs) {
+    push @commands, "service $srvObj";
   }
 
   # 推送访问控制时间策略
@@ -166,8 +102,50 @@ sub createRule {
   push @commands, "quit";
 
   # 返回计算结果
-  $self->addToCommandText(@commands);
-} ## end sub createRule
+  $self->addCommands(@commands);
+}
+
+#------------------------------------------------------------------------------
+# 修改策略对象
+# FIXME 暂不支持华为防火墙策略修改
+#------------------------------------------------------------------------------
+sub modifyRule {
+  my $self    = shift;
+  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{add});
+
+  # if (my $param = $self->searcherReportFwInfo->action->{new}) {
+  #   for my $type (keys %{$param}) {
+  #     if ($type eq 'natDst' or $type eq 'natSrc') {
+  #       $self->createNat($param->{$type}, $type);
+  #     }
+  #   }
+  # }
+
+  # 初始化防火墙策略数组
+  my $policyId = $self->{searcherReportFwInfo}{ruleObj}{policyId};
+  my @commands;
+  push @commands, "security-policy";
+  push @commands, "rule name $policyId";
+  for my $type (keys %{$nameMap}) {
+    if ($type eq 'src') {
+      for my $host (@{$nameMap->{$type}}) {
+        push @commands, "source-address $host";
+      }
+    }
+    elsif ($type eq 'dst') {
+      for my $host (@{$nameMap->{$type}}) {
+        push @commands, "destination-address $host";
+      }
+    }
+    elsif ($type eq 'srv') {
+      for my $srv (@{$nameMap->{$type}}) {
+        push @commands, "service $srv";
+      }
+    }
+  }
+  push @commands, "exit";
+  $self->addCommands(@commands);
+}
 
 #------------------------------------------------------------------------------
 # createAddress 创建地址对象
@@ -176,51 +154,40 @@ sub createAddress {
   my ($self, $addrMap, $srcOrDst) = @_;
 
   # 初始化 cmdStr
-  my ($cmdStr, @commands);
+  my ($config, @commands);
   my $direction = ($srcOrDst eq "src") ? "source-address" : ($srcOrDst eq "dst") ? "destination-address" : undef;
 
   # 遍历 addrMap
   foreach my $addr (@{$addrMap}) {
-
-    # 初始化 ip mask
     my ($ip, $mask) = split('/', $addr);
-
-    # 情况1：单个地址或子网
     if (defined $mask and $mask == 0) {
-      $cmdStr = "$direction any";
-      push @commands, $cmdStr;
+      $config = "$direction any";
+      push @commands, $config;
     }
     elsif (defined $mask and $mask) {
       $mask   = Firewall::Utils::Ip->changeMaskToIpForm($mask);
-      $cmdStr = "$direction $ip mask $mask" if defined $direction;
-      push @commands, $cmdStr;
+      $config = "$direction $ip mask $mask" if defined $direction;
+      push @commands, $config;
     }
-
-    # 情况2：连续地址段
     else {
-      if ($ip
-        =~ /^(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?)-(2[0-4]\d|25[0-5]|1?\d\d?)$/
-        )
-      {
+      if ($ip =~ /^(2[0-4]\d|25[0-5]|1?\d\d?\.){3}(2[0-4]\d|25[0-5]|1?\d\d?)-(2[0-4]\d|25[0-5]|1?\d\d?)$/) {
         my ($ipMin, $ipMax) = split("-", $ip);
         $ipMax  = $1 . $2 . $3 . $5;
-        $cmdStr = "$direction range $ipMin $ipMax" if defined $direction;
-        push @commands, $cmdStr;
+        $config = "$direction range $ipMin $ipMax" if defined $direction;
+        push @commands, $config;
       }
     }
-  } ## end foreach my $addr ( @{$addrMap...})
+  }
 
   # 返回计算结果
   return @commands;
-} ## end sub createAddress
+}
 
 #------------------------------------------------------------------------------
 # createService 新增服务端口命令行配置命令行
 #------------------------------------------------------------------------------
 sub createService {
   my ($self, $srv) = @_;
-
-  # 初始化 serviceName dstPort commands
   my ($serviceName, $dstPort, @commands);
 
   # 拆解 protocol port
@@ -230,19 +197,14 @@ sub createService {
   # 仅支持 TCP/UDP 需要指定端口
   return if $protocol ne 'tcp' and $protocol ne 'udp';
 
-  # 情况1：连续端口
   if ($port =~ /^(?<portMin>\d+)\-(?<portMax>\d+)$/o) {
     $serviceName = $protocol . "_" . $+{portMin} . "-" . $+{portMax};
     $dstPort     = $+{portMin} . " to " . $+{portMax};
   }
-
-  # 情况2：单一端口
   elsif ($port =~ /^\d+$/o) {
     $serviceName = $protocol . "_" . $port;
     $dstPort     = $port;
   }
-
-  # 未匹配的端口信息
   else {
     confess "ERROR: $port is not a port";
   }
@@ -253,9 +215,9 @@ sub createService {
   push @commands, "quit";
 
   # 返回计算结果
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $serviceName;
-} ## end sub createService
+}
 
 #------------------------------------------------------------------------------
 # createSchedule 新增时间策略命令行
@@ -267,8 +229,8 @@ sub createSchedule {
   my @commands;
 
   # 获取起止时间属性
-  my $startDate = $schedule->{"startdate"};
-  my $endDate   = $schedule->{"enddate"};
+  my $startDate = $schedule->{startdate};
+  my $endDate   = $schedule->{enddate};
 
   # 如果未定义起止时间则跳过
   return if not defined $startDate;
@@ -276,7 +238,7 @@ sub createSchedule {
   # 分割时间
   my ($syear, $smon, $sday, $shh, $smm) = split('[ :-]', $startDate);
   my ($year,  $mon,  $day,  $hh,  $mm)  = split('[ :-]', $endDate);
-  my $schName = sch_ $year - $mon - $day;
+  my $schName = "sch_$year-$mon-$day";
 
   # 推送配置
   push @commands, "time-range $schName";
@@ -284,9 +246,9 @@ sub createSchedule {
   push @commands, "quit";
 
   # 返回计算属性
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $schName;
-} ## end sub createSchedule
+}
 
 #------------------------------------------------------------------------------
 # createAddrGroup 新增地址组命令行
@@ -298,7 +260,7 @@ sub createAddrGroup {
   my (@addrs, @commands);
 
   # 初始化防火墙解析对象
-  my $parser = $self->{"searcherReportFwInfo"}{"parser"};
+  my $parser = $self->{searcherReportFwInfo}{parser};
 
   # 创建随机地址组
   my $groupId   = sprintf('%d', 100 + int(rand(10000)));
@@ -312,7 +274,7 @@ sub createAddrGroup {
   push @commands, "ip address-set $groupName type object";
 
   # 转换 addrMap 为集合对象
-  my $addrSet = Firewall::Utils::Set->new();
+  my $addrSet = Firewall::Utils::Set->new;
   for my $addr (@{$addrMap}) {
     my ($ip, $mask) = split('/', $addr);
     $addrSet->mergeToSet(Firewall::Utils::Ip->getRangeFromIpMask($ip, $mask));
@@ -320,34 +282,28 @@ sub createAddrGroup {
 
   # 遍历区间集合，重组 $addrs (有可能连续的地址可缩写)
   for (my $i = 0; $i < $addrSet->length; $i++) {
-    my $min = $addrSet->{"mins"}[$i];
-    my $max = $addrSet->{"maxs"}[$i];
+    my $min = $addrSet->{mins}[$i];
+    my $max = $addrSet->{maxs}[$i];
     push @addrs, Firewall::Utils::Ip->getIpMaskFromRange($min, $max);
   }
 
   # 遍历 addrs
   for my $addr (@addrs) {
-
-    # 情况1：匹配连续地址段
     if ($addr =~ /\-/) {
       my ($ipMin, $ipMax) = split('-', $addr);
       push @commands, "address range $ipMin $ipMax";
     }
-
-    # 情况2：单个地址或子网
     else {
       my ($ip, $mask) = split('/', $addr);
       push @commands, "address $ip mask $mask";
     }
   }
-
-  # 推送代码块结束命令行
   push @commands, "quit";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
 
   # 返回计算结果
   return $groupName;
-} ## end sub createAddrGroup
+}
 
 #------------------------------------------------------------------------------
 # isNewVer 检测是否为新版本防火墙
@@ -356,7 +312,7 @@ sub isNewVer {
   my $self = shift;
 
   # 获取防火墙版本信息
-  my $version = $self->{"searcherReportFwInfo"}{"parser"}{"version"};
+  my $version = $self->{searcherReportFwInfo}{parser}{version};
 
   # 判断防火墙版本
   if (defined $version) {
@@ -368,77 +324,21 @@ sub isNewVer {
 }
 
 #------------------------------------------------------------------------------
-# createPool 新增 natPool
+# 查询或创建地址转换
 #------------------------------------------------------------------------------
-sub createPool {
-  my ($self, $natIp, $type) = @_;
-
-  # 初始化 commands
-  my @commands;
-
-  #  初始化 poolName
-  my $ipRange
-    = qr/(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?)-(2[0-4]\d|25[0-5]|1?\d\d?)/;
-  my $ipAndMask
-    = qr/(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?\.)(2[0-4]\d|25[0-5]|1?\d\d?)/;
-  my $poolName = "natPool_$natIp";
-
-  # 情况1：源地址动态NAT
-  if ($type eq 'natSrc') {
-    push @commands, "nat address-group $poolName";
-    push @commands, "mode pat";
-  }
-
-  # 情况2：目的地址动态NAT
-  elsif ($type eq 'natDst') {
-    push @commands, "destination-nat address-group $poolName";
-  }
-
-  # 情况1：natIp匹配连续地址段
-  if ($natIp =~ $ipRange) {
-    my ($ipMin, $ipMax) = split('-', $natIp);
-    $ipMax = $1 . $2 . $3 . $5;
-    push @commands, "section $ipMin $ipMax";
-  }
-
-  # 情况2：natIp匹配单个地址或子网
-  elsif ($natIp =~ $ipAndMask) {
-    my ($ip, $mask) = split('/', $natIp);
-    $mask = 32 if not defined $mask;
-    my ($min, $max) = Firewall::Utils::Ip->getRangeFromIpMask($ip, $mask);
-    my $ipMin = Firewall::Utils::Ip->changeIntToIp($min);
-    my $ipMax = Firewall::Utils::Ip->changeIntToIp($max);
-    push @commands, "section $ipMin $ipMax";
-  }
-
-  # 推送代码块结束命令行
-  push @commands, "quit";
-  $self->addToCommandText(@commands);
-
-  # 返回计算结果
-  return $poolName;
-} ## end sub createPool
-
-#------------------------------------------------------------------------------
-# createPool 新增 natPool
-#------------------------------------------------------------------------------
-sub newCheckAndCreateNat {
-
-}
-
 sub checkAndCreateNat {
   my ($self, $param) = @_;
+  return unless $self->isNewVer;
 
-  return unless $self->isNewVer();
   my @commands;
-  my $ippat = '\d+\.\d+\.\d+\.\d+';
+  my $ipRegex = qr/(2[0-4]\d|25[0-5]|1?\d\d?\.){3}(2[0-4]\d|25[0-5]|1?\d\d?)/;
   push @commands, "nat-policy";
   my $randNum  = sprintf('%05d', int(rand(99999)));
   my $timeNow  = Firewall::Utils::Date->getFormatedDate('yyyymmdd_hhmiss') . "_$randNum";
   my $ruleName = "policy_nat_$timeNow";
-  my $fromZone = $self->{"searcherReportFwInfo"}{"fromZone"};
-  my $toZone   = $self->{"searcherReportFwInfo"}{"toZone"};
-  my $srvMap   = $self->{"searcherReportFwInfo"}{"srvMap"};
+  my $fromZone = $self->{searcherReportFwInfo}{fromZone};
+  my $toZone   = $self->{searcherReportFwInfo}{toZone};
+  my $srvMap   = $self->{searcherReportFwInfo}{srvMap};
   push @commands, "rule name $ruleName";
   push @commands, "source-zone $fromZone";
   push @commands, "destination-zone $toZone";
@@ -451,8 +351,8 @@ sub checkAndCreateNat {
     $mask = 32 if not defined $mask;
     my ($mip, $mmask) = split('/', $natIp);
     $mmask = 32 if not defined $mmask;
-    if ($type eq 'natSrc') {
 
+    if ($type eq 'natSrc') {
       if (not defined $natIp) {
         my ($ip, $mask) = split('/', $realIp);
         $mask = 32 if not defined $mask;
@@ -470,14 +370,13 @@ sub checkAndCreateNat {
       }
     }
     elsif ($type eq 'natDst') {
-      if ($natIp =~ /$ippat\/\d+/) {
+      if ($natIp =~ /$ipRegex\/\d+/) {
         my ($ip, $mask) = split('/', $natIp);
         push @commands, "destination-address $ip $mask";
       }
-      elsif ($natIp =~ /$ippat-$ippat/) {
+      elsif ($natIp =~ /$ipRegex-$ipRegex/) {
         my ($ipMin, $ipMax) = split('-', $natIp);
         push @commands, "destination-address range $ipMin $ipMax";
-
       }
       my $natPort = "";
       for my $srv (keys %{$srvMap}) {
@@ -490,29 +389,20 @@ sub checkAndCreateNat {
       my $poolName = $self->createPool($natIp, $type);
       push @commands, "action destination-nat address-group $poolName $natPort";
       push @commands, "quit";
-
-    } ## end elsif ( $type eq 'natDst')
-
-  } ## end for my $type ( keys %{$param...})
-  $self->addToCommandText(@commands);
-} ## end sub checkAndCreateNat
-
-sub createDynamicNat {
-
-}
-
-sub createStaticNat {
-
+    }
+  }
+  $self->addCommands(@commands);
 }
 
+#------------------------------------------------------------------------------
+# 查询或创建地址转换
+#------------------------------------------------------------------------------
 sub getPoolName {
   my ($self, $toZone, $natIp) = @_;
-
-  # 初始化 poolName
   my $poolName;
 
   # 初始化 parser
-  my $parser = $self->{"searcherReportFwInfo"}{"parser"};
+  my $parser = $self->{searcherReportFwInfo}{parser};
 
   # 转换 natIp 为集合对象
   my ($ip, $mask) = split('/', $natIp);
@@ -520,15 +410,80 @@ sub getPoolName {
   my $natIpSet = Firewall::Utils::Ip->getRangeFromIpMask($ip, $mask);
 
   # 遍历已有 natPool
-  for my $natPool (values %{$parser->{"elements"}{"natPool"}}) {
-    if ($natPool->{"zone"} eq $toZone and $natPool->{"poolRange"}->isContain($natIpSet)) {
-      $poolName = $natPool->{"poolName"};
-
-      # 找到即停
+  for my $natPool (values %{$parser->{elements}{natPool}}) {
+    if ($natPool->{zone} eq $toZone and $natPool->{poolRange}->isContain($natIpSet)) {
+      $poolName = $natPool->{poolName};
       return $poolName;
     }
   }
-} ## end sub getPoolName
+}
+
+#------------------------------------------------------------------------------
+# createPool 新增 natPool
+#------------------------------------------------------------------------------
+sub createPool {
+  my ($self, $natIp, $type) = @_;
+
+  # 初始化 commands
+  my @commands;
+
+  #  初始化 poolName
+  my $ipRange   = qr/(2[0-4]\d|25[0-5]|1?\d\d?\.){3}(2[0-4]\d|25[0-5]|1?\d\d?)-(2[0-4]\d|25[0-5]|1?\d\d?)/;
+  my $ipAndMask = qr/(2[0-4]\d|25[0-5]|1?\d\d?\.){3}(2[0-4]\d|25[0-5]|1?\d\d?)/;
+  my $poolName  = "natPool_$natIp";
+
+  if ($type eq 'natSrc') {
+    push @commands, "nat address-group $poolName";
+    push @commands, "mode pat";
+  }
+  elsif ($type eq 'natDst') {
+    push @commands, "destination-nat address-group $poolName";
+  }
+
+  if ($natIp =~ $ipRange) {
+    my ($ipMin, $ipMax) = split('-', $natIp);
+    $ipMax = $1 . $2 . $3 . $5;
+    push @commands, "section $ipMin $ipMax";
+  }
+  elsif ($natIp =~ $ipAndMask) {
+    my ($ip, $mask) = split('/', $natIp);
+    $mask = 32 if not defined $mask;
+    my ($min, $max) = Firewall::Utils::Ip->getRangeFromIpMask($ip, $mask);
+    my $ipMin = Firewall::Utils::Ip->changeIntToIp($min);
+    my $ipMax = Firewall::Utils::Ip->changeIntToIp($max);
+    push @commands, "section $ipMin $ipMax";
+  }
+  push @commands, "quit";
+  $self->addCommands(@commands);
+
+  # 返回计算结果
+  return $poolName;
+}
+
+#------------------------------------------------------------------------------
+# 查询或创建地址转换
+#------------------------------------------------------------------------------
+sub createDyNat { }
+
+#------------------------------------------------------------------------------
+# 查询或创建地址转换
+#------------------------------------------------------------------------------
+sub createStaticNat { }
+
+#------------------------------------------------------------------------------
+# 创建原地址对象
+#------------------------------------------------------------------------------
+sub createSrc { }
+
+#------------------------------------------------------------------------------
+# 创建目的地址对象
+#------------------------------------------------------------------------------
+sub createDst { }
+
+#------------------------------------------------------------------------------
+# 创建服务端口对象
+#------------------------------------------------------------------------------
+sub createSrv { }
 
 __PACKAGE__->meta->make_immutable;
 1;
