@@ -18,7 +18,7 @@ has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Rep
 
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
-sub addToCommandText {
+sub addCommands {
   my ($self, @commands) = @_;
   push @{$self->commandText}, @commands;
 }
@@ -52,7 +52,7 @@ sub design {
     push @{$self->commandText}, 'save config';
   }
   return join('', map {"$_\n"} @{$self->commandText});
-} ## end sub design
+}
 
 sub createRule {
   my $self   = shift;
@@ -101,10 +101,10 @@ sub createRule {
       }
     }
 
-  } ## end for my $type ( keys %{$nameMap...})
+  }
   push @commands, "exit";
-  $self->addToCommandText(@commands);
-} ## end sub createRule
+  $self->addCommands(@commands);
+}
 
 sub modifyRule {
   my $self    = shift;
@@ -140,13 +140,13 @@ sub modifyRule {
 
     }
 
-  } ## end for my $type ( keys %{$nameMap...})
+  }
 
   push @commands, qq{exit};
 
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
 
-} ## end sub modifyRule
+}
 
 sub checkAndCreateAddrOrSrvOrNat {
   my ($self, $param) = @_;
@@ -169,7 +169,7 @@ sub checkAndCreateAddrOrSrvOrNat {
     }
   }
   return $nameMap;
-} ## end sub checkAndCreateAddrOrSrvOrNat
+}
 
 sub createNat {
   my ($self, $param, $type) = @_;
@@ -199,7 +199,7 @@ policy mip policy_name before_trans_ipaddress after_trans_ipaddress
   my $natName = "nat_" . $natIp;
   my @commands;
   push @commands, "policy mip $natName $natInfo->{realIp} $natIp enable";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
 
 }
 
@@ -261,7 +261,7 @@ sub createDyNat {
             }
           }
           push @commands, "policy snat_$poliName iplist $iplist iplist $natIpList";
-        } ## end else [ if ( not defined $natInfo...)]
+        }
 
       }
       elsif ($type eq 'natDst') {
@@ -273,11 +273,11 @@ sub createDyNat {
         }
 
       }
-    } ## end for my $natIps ( values...)
-  } ## end for my $type ( keys %{$param...})
+    }
+  }
   push @commands, qq{exit};
-  $self->addToCommandText(@commands);
-} ## end sub createDyNat
+  $self->addCommands(@commands);
+}
 
 sub getOrCreatePool {
   my ($self, $natInfo) = @_;
@@ -327,10 +327,10 @@ end
   push @commands, "set startip $startIp";
   push @commands, "next";
   push @commands, "end";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $poolName;
 
-} ## end sub getOrCreatePool
+}
 
 sub createSrc {
   my ($self, $addr) = @_;
@@ -381,9 +381,9 @@ sub createAddress {
   my @commands;
   push @commands, "object ipaddr $addressName $ipString";
   push @commands, "exit";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $addressName;
-} ## end sub createAddress
+}
 
 sub createService {
   my ($self,     $srv)  = @_;
@@ -411,9 +411,9 @@ sub createService {
   my @commands;
   push @commands, "object service $serviceName $protocol 1-65535 $dstPort";
   push @commands, "exit";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $serviceName;
-} ## end sub createService
+}
 
 sub createSchedule {
   my ($self, $schedule) = @_;
@@ -430,10 +430,10 @@ sub createSchedule {
     push @commands, "absolute end $mon/$day/$year $hh:$mm";
   }
   push @commands, "exit";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return "$year-$mon-$day";
 
-} ## end sub createSchedule
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
