@@ -18,7 +18,7 @@ has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Rep
 
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
-sub addToCommandText {
+sub addCommands {
   my ($self, @commands) = @_;
   push @{$self->commandText}, @commands;
 }
@@ -51,7 +51,7 @@ sub design {
     push @{$self->commandText}, 'save';
   }
   return join('', map {"$_\n"} @{$self->commandText});
-} ## end sub design
+}
 
 sub createRule {
   my $self = shift;
@@ -107,8 +107,8 @@ exit
     push @commands, qq{exit};
   }
 
-  $self->addToCommandText(@commands);
-} ## end sub createRule
+  $self->addCommands(@commands);
+}
 
 sub modifyRule {
   my $self = shift;
@@ -142,9 +142,9 @@ sub modifyRule {
   push @commands, @addMemeberCommands;
   push @commands, qq{exit};
 
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
 
-} ## end sub modifyRule
+}
 
 sub checkAndCreateAddrOrSrvOrNat {
   my ($self, $param) = @_;
@@ -174,7 +174,7 @@ sub checkAndCreateAddrOrSrvOrNat {
     }
   }
   return $nameMap;
-} ## end sub checkAndCreateAddrOrSrvOrNat
+}
 
 sub createNat {
   my ($self, $param, $type) = @_;
@@ -204,7 +204,7 @@ sub createStaticNat {
   my $maskString = Firewall::Utils::Ip->new->changeMaskToIpForm($mask);
   my @commands;
   push @commands, "set interface $interface mip $natIp host $realIp netmask $maskString";
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
 
 }
 
@@ -229,10 +229,10 @@ sub createDyNat {
         push @ips, $natInfo->{natIp};
       }
       push @natStrs, {natStr => "$natDirection $poolName", ips => \@ips};
-    } ## end for my $natIps ( values...)
-  } ## end for my $type ( keys %{$param...})
+    }
+  }
   return \@natStrs;
-} ## end sub createDyNat
+}
 
 sub getOrCreatePool {
   my ($self, $natInfo) = @_;
@@ -268,9 +268,9 @@ sub getOrCreatePool {
   else {
     push @commands, "set interface $interfaceName ext ip $ipmin $maskStr dip $randNum $ipmin $ipmax";
   }
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return "dip-id " . $randNum;
-} ## end sub getOrCreatePool
+}
 
 sub createSrc {
   my ($self, $addr, $requestNat) = @_;
@@ -310,7 +310,7 @@ sub createAddress {
     }
     my $maskString = Firewall::Utils::Ip->new->changeMaskToIpForm($mask);
     my $command    = qq{set address "$zoneName" "$addressName" $ipString $maskString};
-    $self->addToCommandText($command);
+    $self->addCommands($command);
   }
   else {
     if ($mask == 32) {
@@ -322,7 +322,7 @@ sub createAddress {
         $addressName = "$ip/32";
         my $maskString = Firewall::Utils::Ip->new->changeMaskToIpForm($mask);
         my $command    = qq{set address "$zoneName" "$addressName" $ip $maskString};
-        $self->addToCommandText($command);
+        $self->addCommands($command);
       }
     }
     else {
@@ -335,13 +335,13 @@ sub createAddress {
         $addressName = "$ipString/$mask";
         my $maskString = Firewall::Utils::Ip->new->changeMaskToIpForm($mask);
         my $command    = qq{set address "$zoneName" "$addressName" $ipString $maskString};
-        $self->addToCommandText($command);
+        $self->addCommands($command);
       }
     }
 
-  } ## end else [ if ( $zoneName ne 'Global')]
+  }
   return $addressName;
-} ## end sub createAddress
+}
 
 sub createService {
   my ($self, $srv) = @_;
@@ -380,9 +380,9 @@ sub createService {
 
   }
   my $command = qq{set service "$serviceName" protocol $protocol src-port 0-65535 dst-port $dstPort};
-  $self->addToCommandText($command);
+  $self->addCommands($command);
   return $serviceName;
-} ## end sub createService
+}
 
 sub createSchedule {
   my ($self, $schedule) = @_;
@@ -401,10 +401,10 @@ sub createSchedule {
   my ($year, $mon, $day, $hh, $mm) = split('[ :-]', $schedule->{enddate});
   my $schName = "$year-$mon-$day";
   my $command = qq{set scheduler "$schName" once start $smon/$sday/$syear $shh:$smm stop $mon/$day/$year $hh:$mm};
-  $self->addToCommandText($command);
+  $self->addCommands($command);
   return $schName;
 
-} ## end sub createSchedule
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
