@@ -10,156 +10,84 @@ use namespace::autoclean;
 # 加载项目模块
 #------------------------------------------------------------------------------
 use Firewall::Utils::Date;
-use Firewall::Policy::Searcher::Report::FwInfo;
 
-has dbi => (is => 'ro', does => 'Firewall::DBI::Role', required => 1,);
-
-has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Report::FwInfo', required => 1,);
-
-has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
-
-sub addToCommandText {
-  my ($self, @commands) = @_;
-  push @{$self->commandText}, @commands;
-}
-
-sub design {
-  my $self = shift;
-  if ($self->searcherReportFwInfo->type eq 'new') {
-    $self->createRule;
-  }
-  elsif ($self->searcherReportFwInfo->type eq 'modify') {
-    $self->modifyRule;
-  }
-  elsif ($self->searcherReportFwInfo->type eq 'ignore') {
-    if (defined $self->searcherReportFwInfo->action) {
-      my $param = $self->searcherReportFwInfo->action->{'new'};
-      for my $type (keys %{$param}) {
-        if ($type eq 'natDst' or $type eq 'natSrc') {
-          $self->createNat($param->{$type});
-        }
-      }
-    }
-  }
-  else {
-    confess("ERROR: searcherReportFwInfo->type(" . $self->searcherReportFwInfo->type . ") must be 'new' or 'modify'");
-  }
-  if (@{$self->commandText} > 0) {
-    push @{$self->commandText}, 'commit check';
-    push @{$self->commandText}, 'commit';
-  }
-  return join('', map {"$_\n"} @{$self->commandText});
-} ## end sub design
+#------------------------------------------------------------------------------
+# 继承 Firewall::Policy::Designer::Role 方法和属性
+#------------------------------------------------------------------------------
+with 'Firewall::Policy::Designer::Role';
 
+#------------------------------------------------------------------------------
+# JUNIPER防火墙策略设计相关模块
+#------------------------------------------------------------------------------
 sub createRule {
   my $self = shift;
 
-  #先检查涉及到的 addr or srv 在防火墙上有没有已经存在的名字，没有就需要创建
-  my $action  = $self->searcherReportFwInfo->action;
-  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($action->{'new'});
-
-=example
-set security policies from-zone l2-untrust to-zone l2-trust policy p409 match source-address host_10.39.100.252
-set security policies from-zone l2-untrust to-zone l2-trust policy p409 match destination-address host_10.44.96.12
-set security policies from-zone l2-untrust to-zone l2-trust policy p409 match application tcp_44441-44444
-set security policies from-zone l2-untrust to-zone l2-trust policy p409 then permit
-
-=cut
-
+  # 先检查涉及到的 addr or srv 在防火墙上有没有已经存在的名字，没有就需要创建
+  my $action   = $self->searcherReportFwInfo->action;
+  my $mappings = $self->checkAndCreateAddrOrSrvOrNat($action->{new});
   my ($fromZone, $toZone) = ($self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone);
+
   my @commands;
   my $randNum  = $$ || sprintf('%05d', int(rand(99999)));
   my $ruleName = 'p_' . Firewall::Utils::Date->new->getFormatedDate('yyyymmdd_hhmiss') . "_$randNum";
-  for my $type (keys %{$nameMap}) {
+  for my $type (keys %{$mappings}) {
     push @commands,
       map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match source-address $_"}
-      @{$nameMap->{$type}}
+      @{$mappings->{$type}}
       if $type eq 'src';
     push @commands,
       map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match destination-address $_"}
-      @{$nameMap->{$type}}
+      @{$mappings->{$type}}
       if $type eq 'dst';
     push @commands,
-      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"} @{$nameMap->{$type}}
+      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"}
+      @{$mappings->{$type}}
       if $type eq 'srv';
   }
   push @commands, "set security policies from-zone $fromZone to-zone $toZone policy $ruleName then permit";
-  $self->addToCommandText(@commands);
-} ## end sub createRule
+  $self->addCommands(@commands);
+}
 
+#------------------------------------------------------------------------------
+# JUNIPER防火墙策略调整函数
+#------------------------------------------------------------------------------
 sub modifyRule {
   my $self = shift;
 
-  #先检查涉及到的 addr or srv 在防火墙上有没有已经存在的名字，没有就需要创建
-  my $nameMap = $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{'add'});
-  if ($self->searcherReportFwInfo->action->{'new'}) {
-    $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{'new'});
+  # 先检查涉及到的 addr or srv 在防火墙上有没有已经存在的名字，没有就需要创建
+  my $mappings = $self->checkAndCreateAddrOrSrvOrNat($self->searcherReportFwInfo->action->{add});
+  if (my $action = $self->searcherReportFwInfo->action->{new}) {
+    $self->checkAndCreateAddrOrSrvOrNat($action);
   }
   my ($fromZone, $toZone) = ($self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone);
   my $ruleName = $self->searcherReportFwInfo->ruleObj->ruleName;
 
   my @commands;
-  for my $type (keys %{$nameMap}) {
+  for my $type (keys %{$mappings}) {
     push @commands,
       map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match source-address $_"}
-      @{$nameMap->{$type}}
+      @{$mappings->{$type}}
       if $type eq 'src';
     push @commands,
       map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match destination-address $_"}
-      @{$nameMap->{$type}}
+      @{$mappings->{$type}}
       if $type eq 'dst';
     push @commands,
-      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"} @{$nameMap->{$type}}
+      map {"set security policies from-zone $fromZone to-zone $toZone policy $ruleName match application $_"}
+      @{$mappings->{$type}}
       if $type eq 'srv';
   }
-
-  $self->addToCommandText(@commands);
-
-} ## end sub modifyRule
-
-sub checkAndCreateAddrOrSrvOrNat {
-  my ($self, $param) = @_;
-  my $nameMap;
-  for my $type (keys %{$param}) {
-    if ($type eq 'natDst' or $type eq 'natSrc') {
-      $self->createNat($param->{$type}, $type);
-    }
-    else {
-      for my $addrOrSrv (keys %{$param->{$type}}) {
-        if (not defined $param->{$type}{$addrOrSrv}) {
-          my $func = "create" . (ucfirst $type);    #createSrc, createDst, createSrv
-          push @{$nameMap->{$type}}, $self->$func($addrOrSrv);
-        }
-        else {
-          push @{$nameMap->{$type}}, $param->{$type}{$addrOrSrv}[0];
-        }
-      }
-    }
-  }
-  return $nameMap;
-} ## end sub checkAndCreateAddrOrSrvOrNat
-
-sub createNat {
-  my ($self, $param, $type) = @_;
-  my $dyNatInfo = {};
-  for my $natInfo (values %{$param}) {
-    if ($natInfo->{natInfo}->{natType} eq 'static') {
-      $self->createStaticNat($natInfo);
-    }
-    else {
-      $dyNatInfo->{$type}{$natInfo->{natInfo}}{$natInfo->{realIp}} = $natInfo;
-    }
-  }
-  if (scalar(values %{$dyNatInfo}) != 0) {
-    $self->createDyNat($dyNatInfo);
-  }
+  $self->addCommands(@commands);
 }
 
+#------------------------------------------------------------------------------
+# 静态地址转换
+#------------------------------------------------------------------------------
 sub createStaticNat {
   my ($self, $natInfo) = @_;
 
-  #set security nat static rule-set dmz_static_nat rule host_172_29_16_1 match destination-address 172.29.16.1/32
-  #set security nat static rule-set dmz_static_nat rule host_172_29_16_1 then static-nat prefix 10.11.100.97/32
+  # set security nat static rule-set dmz_static_nat rule host_172_29_16_1 match destination-address 172.29.16.1/32
+  # set security nat static rule-set dmz_static_nat rule host_172_29_16_1 then static-nat prefix 10.11.100.97/32
 
   my $natName = 'host_' . join('_', (split(/[\.\/]/, $natInfo->{natInfo}{natIp}))[0, 1, 2, 3]);
   my @commands;
@@ -169,44 +97,25 @@ sub createStaticNat {
   if (defined $ruleSet) {
     push @commands, "set security nat static rule-set $ruleSet rule $natName match destination-address $natIp";
     push @commands, "set security nat static rule-set $ruleSet rule $natName then static-nat prefix $realIp";
-    $self->addToCommandText(@commands);
+    $self->addCommands(@commands);
   }
   else {
     push @commands, "set security nat static rule-set static-nat rule $natName match destination-address $natIp";
     push @commands, "set security nat static rule-set static-nat rule $natName then static-nat prefix $realIp";
-    $self->addToCommandText(@commands);
+    $self->addCommands(@commands);
   }
-} ## end sub createStaticNat
-
-=example
-set security nat source pool srcnat_pool_3 address 202.69.21.46/32 to 202.69.21.46/32
-set security nat source rule-set dmz_untrust from zone dmz
-set security nat source rule-set dmz_untrust to zone untrust
-set security nat source rule-set dmz_untrust rule rule21 match source-address 172.28.40.47/32
-set security nat source rule-set dmz_untrust rule rule21 match source-address 172.28.40.181/32
-set security nat source rule-set dmz_untrust rule rule21 match destination-address 220.196.52.117/32
-set security nat source rule-set dmz_untrust rule rule21 then source-nat pool srcnat_pool_3
-
-set security nat destination pool dstnat_pool_10 address 172.28.40.47/32
-set security nat destination pool dstnat_pool_23 address 172.28.32.75/32
-set security nat destination pool dstnat_pool_23 address port 80
-
-set security nat destination rule-set untrust_dmz from zone untrust
-set security nat destination rule-set untrust_dmz rule rule22 match source-address 220.196.52.117/32
-set security nat destination rule-set untrust_dmz rule rule22 match destination-address 202.69.21.46/32
-set security nat destination rule-set untrust_dmz rule rule22 match destination-port 8807
-set security nat destination rule-set untrust_dmz rule rule22 then destination-nat pool dstnat_pool_10
-
-set security nat destination rule-set untrust_dmz rule rule23 match destination-address 202.69.21.114/32
-set security nat destination rule-set untrust_dmz rule rule23 match destination-port 80
-set security nat destination rule-set untrust_dmz rule rule23 then destination-nat pool dstnat_pool_23
-=cut
+}
 
+#------------------------------------------------------------------------------
+# 动态地址转换
+#------------------------------------------------------------------------------
 sub createDyNat {
   my ($self, $param) = @_;
   my @commands;
-  my ($fromZone, $toZone) = ($self->searcherReportFwInfo->fromZone, $self->searcherReportFwInfo->toZone);
-  my $srvMap = $self->searcherReportFwInfo->srvMap;
+  my $fromZone = $self->searcherReportFwInfo->fromZone;
+  my $toZone   = $self->searcherReportFwInfo->toZone;
+  my $srvMap   = $self->searcherReportFwInfo->srvMap;
+
   for my $type (keys %{$param}) {
     for my $natIps (values %{$param->{$type}}) {
       my ($natDirection, $ruleSet, $ruleName, $poolName, $natInfo);
@@ -220,7 +129,6 @@ sub createDyNat {
         $ruleSet = $fromZone . '_' . $toZone;
         push @commands, "set security nat $natDirection rule-set $ruleSet from zone $fromZone";
         push @commands, "set security nat $natDirection rule-set $ruleSet to zone $toZone";
-
       }
       else {
         while (defined $self->searcherReportFwInfo->parser->getDynamicNat($ruleSet, $ruleName)) {
@@ -233,7 +141,6 @@ sub createDyNat {
         $poolName = $self->getOrCreatePool($type, $natIps);
         for my $natIp (keys %{$natIps}) {
           push @commands, "set security nat source rule-set $ruleSet rule $ruleName match source-address $natIp";
-
         }
         if (defined $natInfo->{natOption} and $natInfo->{natOption} =~ /d/) {
           for my $dstIp (keys %{$self->searcherReportFwInfo->dstMap}) {
@@ -245,7 +152,7 @@ sub createDyNat {
       }
       elsif ($type eq 'natDst') {
 
-        #需要做端口NAT，可能存在多端口情况，每个端口都需要一套NAT策略
+        # 需要做端口NAT，可能存在多端口情况，每个端口都需要一套NAT策略
         if (defined $natInfo->{natOption} and $natInfo->{natOption} =~ /p/) {
           for my $portInfo (values %{$self->searcherReportFwInfo->srvMap}) {
             $poolName = $self->getOrCreatePool($type, $natIps, $portInfo);
@@ -269,7 +176,7 @@ sub createDyNat {
             my ($pro, $port) = split('/', $natPort);
             push @commands, "set security nat destination rule-set $ruleSet rule $ruleName match destination-port $port";
             push @commands, "set security nat destination rule-set $ruleSet rule $ruleName then destination-nat $poolName";
-          } ## end for my $portInfo ( values...)
+          }
         }
         else {
           $poolName = $self->getOrCreatePool($type, $natIps);
@@ -289,17 +196,16 @@ sub createDyNat {
           push @commands,
             "set security nat destination rule-set $ruleSet rule $ruleName match destination-address $natInfo->{natIp}";
           push @commands, "set security nat destination rule-set $ruleSet rule $ruleName then destination-nat $poolName";
+        }
+      }
+    }
+  }
+  $self->addCommands(@commands) if @commands != 0;
+}
 
-        } ## end else [ if ( defined $natInfo->...)]
-
-      } ## end elsif ( $type eq 'natDst')
-
-    } ## end for my $natIps ( values...)
-  } ## end for my $type ( keys %{$param...})
-  $self->addToCommandText(@commands) if @commands != 0;
-
-} ## end sub createDyNat
-
+#------------------------------------------------------------------------------
+# 查询地址转换池
+#------------------------------------------------------------------------------
 sub getOrCreatePool {
   my ($self, $type, $natIps, $portInfo) = @_;
   my $poolName;
@@ -312,12 +218,11 @@ sub getOrCreatePool {
     else {
       return "interface";
     }
-
   }
   $poolIp = $natInfo->{natIp} if $type eq 'natSrc';
   my $natPools = $self->searcherReportFwInfo->parser->elements->natPool;
 
-  #print dumper $self->searcherReportFwInfo->srvMap;exit;
+  # print dumper $self->searcherReportFwInfo->srvMap;exit;
   $poolIp = $natInfo->{natIp}                if $type eq 'natSrc';
   $poolIp = (values %{$natIps})[0]->{realIp} if $type eq 'natDst';
   $poolIp =~ s/$/\/32/ if $poolIp !~ /\//;
@@ -325,7 +230,6 @@ sub getOrCreatePool {
   my $poolRange = Firewall::Utils::Ip->new->getRangeFromIpMask($ip, $mask);
   my @commands;
   if ($type eq 'natSrc') {
-
     for my $pool (values %{$natPools}) {
       if ($pool->natDirection eq 'source' and $pool->poolRange->isEqual($poolRange)) {
         return "pool " . $pool->poolName;
@@ -341,7 +245,6 @@ sub getOrCreatePool {
       $poolName = "srcnat_pool_$randNum";
     }
     push @commands, "set security nat source pool $poolName address $poolIp to $poolIp";
-
   }
   elsif ($type eq 'natDst') {
     for my $pool (values %{$natPools}) {
@@ -357,9 +260,9 @@ sub getOrCreatePool {
       }
     }
 
-    #没有找到pool,需要新建
-    #set security nat destination pool dstnat_pool_23 address 172.28.32.75/32
-    #set security nat destination pool dstnat_pool_23 address port 80
+    # 没有找到pool,需要新建
+    # set security nat destination pool dstnat_pool_23 address 172.28.32.75/32
+    # set security nat destination pool dstnat_pool_23 address port 80
     my $randNum = sprintf('%05d', int(rand(99999)));
     $poolName = "dstnat_pool_$randNum";
     while (defined $self->searcherReportFwInfo->parser->getNatPool($poolName)) {
@@ -371,31 +274,42 @@ sub getOrCreatePool {
       my ($pro, $port) = split('/', $portInfo->{origin});
       push @commands, "set security nat destination pool $poolName address port $port";
     }
-
-  } ## end elsif ( $type eq 'natDst')
-  $self->addToCommandText(@commands) if @commands != 0;
+  }
+  $self->addCommands(@commands) if @commands != 0;
   return "pool " . $poolName;
-} ## end sub getOrCreatePool
+}
 
+#------------------------------------------------------------------------------
+# 创建源地址对象
+#------------------------------------------------------------------------------
 sub createSrc {
   my ($self, $addr) = @_;
   return $self->createAddress($self->searcherReportFwInfo->fromZone, $addr);
 }
 
+#------------------------------------------------------------------------------
+# 创建目的地址对象
+#------------------------------------------------------------------------------
 sub createDst {
   my ($self, $addr) = @_;
   return $self->createAddress($self->searcherReportFwInfo->toZone, $addr);
 }
 
+#------------------------------------------------------------------------------
+# 创建服务端口对象
+#------------------------------------------------------------------------------
 sub createSrv {
   my ($self, $srv) = @_;
   return $self->createService($srv);
 }
 
+#------------------------------------------------------------------------------
+# 创建地址函数
+#------------------------------------------------------------------------------
 sub createAddress {
   my ($self, $zoneName, $addr) = @_;
 
-  #set security zones security-zone l2-untrust address-book address host_10.35.194.90 10.35.194.90/32
+  # set security zones security-zone l2-untrust address-book address host_10.35.194.90 10.35.194.90/32
   my ($ip, $mask) = split('/', $addr);
   my ($addressName, $ipString, $ipMin, $ipMax);
   if (not defined $mask) {
@@ -403,7 +317,6 @@ sub createAddress {
       ($ipMin, $ipMax) = ($1 . $2 . $3 . $4, $1 . $2 . $3 . $5);
       $addressName = "Range_$ip";
     }
-
   }
   elsif ($mask == 32) {
     $ipString    = $ip;
@@ -416,23 +329,18 @@ sub createAddress {
     $ipString    = Firewall::Utils::Ip->new->getNetIpFromIpMask($ip, $mask);
     $addressName = "Net_$ipString/$mask";
   }
-
   my $command = "set security zones security-zone $zoneName address-book address $addressName $ipString/$mask" if defined $mask;
   $command = "set security zones security-zone $zoneName address-book address $addressName range-address $ipMin to $ipMax"
     if defined $ipMin;
-  $self->addToCommandText($command);
+  $self->addCommands($command);
   return $addressName;
-} ## end sub createAddress
+}
 
+#------------------------------------------------------------------------------
+# 创建服务端口函数
+#------------------------------------------------------------------------------
 sub createService {
-  my ($self, $srv) = @_;
-
-=services
-set applications application tcp_8080 term tcp_8080 protocol tcp
-set applications application tcp_8080 term tcp_8080 source-port 0-65535
-set applications application tcp_8080 term tcp_8080 destination-port 8080-8080
-=cut
-
+  my ($self,     $srv)  = @_;
   my ($protocol, $port) = split('/', $srv);
   $protocol = lc $protocol;
   return if $protocol ne 'tcp' and $protocol ne 'udp';
@@ -455,9 +363,9 @@ set applications application tcp_8080 term tcp_8080 destination-port 8080-8080
   push @commands, "set applications application $serviceName term $serviceName destination-port $dstPort";
 
   # my $command = qq{set service "$serviceName" protocol $protocol src-port 0-65535 dst-port $dstPort};
-  $self->addToCommandText(@commands);
+  $self->addCommands(@commands);
   return $serviceName;
-} ## end sub createService
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
