@@ -6,15 +6,13 @@ package Firewall::Policy::Designer::Topsec;
 use Moose;
 use namespace::autoclean;
 no warnings 'uninitialized';
-use List::Util qw( uniq );
-use Mojo::Util qw(dumper);
+use List::Util qw/uniq/;
 
 #------------------------------------------------------------------------------
 # getAnalyzerReport 获取防火墙策略源目地址、服务端口分析报告
 #------------------------------------------------------------------------------
 use Firewall::Utils::Ip;
 use Firewall::Policy::Searcher::Topsec;
-use Firewall::Policy::Searcher::Report::FwInfo;
 
 #------------------------------------------------------------------------------
 # Firewall::Policy::Designer::Topsec 通用属性
@@ -26,9 +24,9 @@ has searcherReportFwInfo => (is => 'ro', isa => 'Firewall::Policy::Searcher::Rep
 has commandText => (is => 'ro', isa => 'ArrayRef[Str]', default => sub { [] },);
 
 #------------------------------------------------------------------------------
-# addToCommandText 设置 commandText 属性，入参为标量
+# addCommands 设置 commandText 属性，入参为标量
 #------------------------------------------------------------------------------
-sub addToCommandText {
+sub addCommands {
   my ($self, $commands) = @_;
   push @{$self->{"commandText"}}, $commands;
 }
@@ -70,7 +68,7 @@ sub design {
 
   # 拼接数组为字符串并返回
   return join("\n", uniq @{$self->{"commandText"}});
-} ## end sub design
+}
 
 #------------------------------------------------------------------------------
 # createRule 新增策略
@@ -133,14 +131,14 @@ sub createRule {
       # srvStr 前后需要使用 ''
       $srvStr .= "'";
     }
-  } ## end for my $addrOrSrv ( keys...)
+  }
 
   # 拼接成新增策略
   my $cmdStr = "firewall policy add action accept $zoneStr $srcStr $dstStr $srvStr";
 
   # 添加计算结果
-  $self->addToCommandText($cmdStr);
-} ## end sub createRule
+  $self->addCommands($cmdStr);
+}
 
 #------------------------------------------------------------------------------
 # modifyRule 策略修改
@@ -197,10 +195,10 @@ sub modifyRule {
       }
       $srvMem .= "service ' $srvStr' ";
     }
-  } ## end for my $addrOrSrv ( keys...)
+  }
   my $cmdStr = "policy modify id $policyId $srcMem $dstMem $srvMem";
-  $self->addToCommandText($cmdStr);
-} ## end sub modifyRule
+  $self->addCommands($cmdStr);
+}
 
 #------------------------------------------------------------------------------
 # checkAndCreateAddrOrSrvOrNat 创建地址、服务端口或NAT
@@ -235,11 +233,11 @@ sub checkAndCreateAddrOrSrvOrNat {
         }
       }
     }
-  } ## end for my $type ( keys %{$param...})
+  }
 
   # 返回计算结果
   return $nameMap;
-} ## end sub checkAndCreateAddrOrSrvOrNat
+}
 
 #------------------------------------------------------------------------------
 # createNat 创建 NAT 函数入口，支持静态和动态 NAT
@@ -266,7 +264,7 @@ sub createNat {
   if (defined $dyNatInfo) {
     $self->createDyNat($dyNatInfo);
   }
-} ## end sub createNat
+}
 
 #--------------------------------------- ---------------------------------------
 # createStaticNat 创建静态NAT
@@ -307,17 +305,17 @@ sub createStaticNat {
     if ($natDirection eq 'destination') {
       my $zoneStr = "srcarea '$fromZone ' dstarea '$toZone '";
       my $cmdStr  = "nat policy add $zoneStr orig-dst '$natIpName ' trans-dst '$realIpName '";
-      $self->addToCommandText($cmdStr);
+      $self->addCommands($cmdStr);
     }
 
     #情况2：源地址NAT
     elsif ($natDirection eq 'source') {
       my $zoneStr = "srcarea '$fromZone ' dstarea '$toZone '";
       my $cmdStr  = "nat policy add $zoneStr orig-src '$realIpName ' trans-src '$natIpName '";
-      $self->addToCommandText($cmdStr);
+      $self->addCommands($cmdStr);
     }
   }
-} ## end sub createStaticNat
+}
 
 #------------------------------------------------------------------------------
 # createDyNat 动态生成 NAT策略
@@ -371,7 +369,7 @@ sub createDyNat {
             $realIpName = $realIpName->[0];
           }
           $realIpStr .= $realIpName . " ";
-        } ## end for my $realIp ( @{$natIpInfo...})
+        }
         $realIpStr .= "'";
 
         # 情况1：源地址NAT
@@ -394,8 +392,8 @@ sub createDyNat {
           }
 
           $cmdStr .= " trans-src $natIpName";
-          $self->addToCommandText($cmdStr);
-        } ## end if ( $natDirection eq ...)
+          $self->addCommands($cmdStr);
+        }
 
         # 情况2：目的地址NAT
         elsif ($natDirection eq 'natDst') {
@@ -416,12 +414,12 @@ sub createDyNat {
           }
           $cmdStr .= " orig-dst '" . $realIpStr . "'";
           $cmdStr .= " trans-dst $natIpName";
-          $self->addToCommandText($cmdStr);
-        } ## end elsif ( $natDirection eq ...)
-      } ## end for my $natIp ( keys %natIpInfo)
-    } ## end for my $natInfo ( values...)
-  } ## end for my $natDirection ( ...)
-} ## end sub createDyNat
+          $self->addCommands($cmdStr);
+        }
+      }
+    }
+  }
+}
 
 #------------------------------------------------------------------------------
 # createSrc 创建源地址对象
@@ -489,11 +487,11 @@ sub createAddress {
     $cmdStr      = "define subnet add name $addressName ipaddr $ip mask $maskStr";
   }
   $self->{"address"}{$addr} = $addressName;
-  $self->addToCommandText($cmdStr);
+  $self->addCommands($cmdStr);
 
   # 返回计算结果
   return $addressName;
-} ## end sub createAddress
+}
 
 #------------------------------------------------------------------------------
 # Firewall::Policy::Designer::Topsec 通用属性
@@ -528,11 +526,11 @@ sub createService {
   else {
     confess "ERROR: $port is not a port";
   }
-  $self->addToCommandText($cmdStr);
+  $self->addCommands($cmdStr);
 
   # 返回计算结果
   $serviceName;
-} ## end sub createService
+}
 
 __PACKAGE__->meta->make_immutable;
 1;
